@@ -3,12 +3,14 @@ import json
 import os
 import unittest
 import types
+import responses
 
 import click.testing
 from click.testing import CliRunner
 
 from launchable.__main__ import main
 from launchable.utils.session import clean_session_files
+from launchable.utils.http_client import get_base_url
 
 
 class CliTestCase(unittest.TestCase):
@@ -28,6 +30,14 @@ class CliTestCase(unittest.TestCase):
         self.maxDiff = None
         os.environ['LAUNCHABLE_TOKEN'] = self.launchable_token
 
+        responses.add(responses.POST, "{}/intake/organizations/{}/workspaces/{}/builds/{}/test_sessions".format(get_base_url(), self.organization, self.workspace, self.build_name),
+                      json={'id': self.session_id}, status=200)
+        responses.add(responses.POST, "{}/intake/organizations/{}/workspaces/{}/subset".format(get_base_url(), self.organization, self.workspace),
+                      json={'testPaths': []}, status=200)
+
+        responses.add(responses.POST, "{}/intake/organizations/{}/workspaces/{}/subset".format(get_base_url(), self.organization, self.workspace,),
+                      json={'testPaths': []}, status=200)
+
     def tearDown(self):
         clean_session_files()
 
